﻿// Copyright (c) Strange Loop Games. All rights reserved.
// See LICENSE file in the project root for full license information.

using Eco.Gameplay.Utils;
using Eco.Shared.Localization;
using Eco.Shared.Services;

namespace Eco.Mods
{
    using Eco.Core.Plugins.Interfaces;
    using Eco.Core.Utils;
    using Eco.Gameplay.Players;

    /// <summary> Add star to player. </summary>
    class StartStar : IModKitPlugin, IInitializablePlugin
    {
        private int pointToAdd = 1;
        
        public string GetStatus() => string.Empty;

        public void Initialize(TimedTask timer)
        {
            UserManager.OnNewUserJoined.Add(user =>
            {
                user.SpecialtyPoints = 2 + pointToAdd;
                SendMessage(user);
            });
            
            UserManager.OnUserLoggedIn.Add(user =>
            {
                if (user.SpecialtyPoints == 1 || user.SpecialtyPoints == 2)
                {
                    user.SpecialtyPoints = 2 + pointToAdd;
                    SendMessage(user);
                }
            });
            
            UserManager.OnUserLoggedOut.Add(user =>
            {
                
            });
        }

        void SendMessage(User user)
        {
            user.Player.Msg(Localizer.Format("Вам добавлено {0} бонусных стартовых звезд", pointToAdd));
        }

    }
    
}
